betty.extension.nginx.artifact module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.nginx.artifact module

Build nginx and Docker artifacts, such as configuration files.

async betty.extension.nginx.artifact.generate_configuration_file(project: Project, destination_file_path: Path | None = None, www_directory_path: str | None = None, https: bool | None = None) → None

  Generate an `nginx.conf` file to the given destination path.

async betty.extension.nginx.artifact.generate_dockerfile_file(project: Project, destination_file_path: Path | None = None) → None

  Generate a `Dockerfile` to the given destination path.